@@ -67,6 +67,7 @@
 #include "cgdbrc.h"
 #include "io.h"
 #include "tgdb_list.h"
+#include "terminal.h"
 
 /* --------------- */
 /* Local Variables */
@@ -270,6 +271,10 @@ static int user_input(void) {
     static int key, val;
     
 	key = kui_manager_getkey ( kui_ctx );
+    if (key == -1) {
+        logger_write_pos ( logger, __FILE__, __LINE__, "kui_manager_getkey error");
+        return -1;
+    }
 
     /* Process the key */
     switch ( ( val = if_input(key)) ) {
@@ -507,14 +512,20 @@ static int tgdb_readline_input(void){
 }
 
 static int cgdb_resize_term(int fd) {
-    int c;
+    int c, result;
     read(resize_pipe[0], &c, sizeof(int) );
 
 	/* If there is more input in the pipe, that means another resize has
 	 * been recieved, and we still have not handled this one. So, skip this
 	 * one and only handle the next one.
 	 */
-	if ( io_data_ready( resize_pipe[0], 0 ) ) {
+	result = io_data_ready( resize_pipe[0], 0 );
+    if (result == -1) {
+        logger_write_pos ( logger, __FILE__, __LINE__, "io_data_ready");
+        return -1;
+    }
+
+    if (result) {
 		if_print ( "skip signal\n" );
 		return 0;
 	}
@@ -632,6 +643,8 @@ void cleanup()
     /* Shut down debugger */
     tgdb_shutdown( tgdb );
 
+    tty_reset(STDIN_FILENO);
+
 	if ( has_recv_data )
 		fprintf ( stderr, "CGDB had unexpected results, see %s for details.\n", log_file );
 
@@ -678,6 +691,12 @@ int main(int argc, char *argv[]) {
         exit(-1);
 	}
 
+    if ( tty_cbreak(STDIN_FILENO) == -1 ) {
+        logger_write_pos ( logger, __FILE__, __LINE__, "tty_cbreak error");
+        cleanup();
+        exit(-1);
+	}
+
 	kui_ctx = kui_manager_create ( STDIN_FILENO );
 	if ( !kui_ctx  ) {
         logger_write_pos ( logger, __FILE__, __LINE__, "Unable to initialize input library"); 
