@@ -152,10 +152,6 @@ static int init_curses()
        fprintf(stderr, "(%s:%d) putenv failed\r\n", __FILE__, __LINE__);
 
     initscr();                       /* Start curses mode */
-    cbreak();                        /* Line buffering disabled */
-    noecho();                        /* Do not echo characters typed by user */
-    keypad(stdscr, TRUE);            /* Translate arrow keys, Fn keys, etc. */
-    timeout(0);                      /* Use non-blocking I/O */
 
     if ((curses_colors = has_colors())){
         start_color();
@@ -1296,12 +1292,8 @@ void if_filedlg_display_message(char *message) {
 void if_shutdown(void)
 {
     /* Shut down curses cleanly */
-    if (curses_initialized){
-        /*nocbreak(); */
-        keypad(stdscr, FALSE); 
-        echo();
+    if (curses_initialized)
         endwin();
-    }
 
     if ( status_win != NULL )
         delwin(status_win);
